==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/core/classes/Config/ConfigArray.php <==
<?php
namespace Claromentis\Core\Config;

$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] ?: array()) + array("_bd71c3b5c2" . "01fc11db82e" . "d14ce424de5" => base64_decode("aW5" . "fYX" . "JyY" . "Xk="));




class ConfigArray implements WritableConfig
{
    
    
    
    
    protected array $config;
    
    
    
    
    
    
    protected ?array $writableKeys;
    
    
    
    
    
    
    
    public function __construct(array $config = [], ?array $_e6592e635ebb74d430b5d3bac59df55b = null)
    {
        $this->config = $config;
        $this->writableKeys = $_e6592e635ebb74d430b5d3bac59df55b;
    }
    public function has(string $key) : bool
    {
        return isset($this->config[$key]);
    }
    public function get($key)
    {
        return $this->config[$key] ?? null;
    }
    public function getAll() : array
    {
        return $this->config;
    }
    public function set($key, $value) : void
    {
        if (!$this->canSet($key)) {
            return;
        }
        $this->config[$key] = $value;
    }
    public function setMany(array $values) : void
    {
        foreach ($values as $key => $value) {
            $this->set($key, $value);
        }
    }
    public function delete($key) : void
    {
        if ($this->canSet($key)) {
            unset($this->config[$key]);
        }
    }
    public function save() : void
    {
        
        
    }
    public function canSet(string $key) : bool
    {
        return $this->writableKeys === null || $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_bd71c3b5c201fc11db82ed14ce424de" . "5"]($key, $this->getWritableKeys());
    }
    
    
    
    
    
    
    public function getWritableKeys() : ?array
    {
        return $this->writableKeys;
    }
    
    
    
    
    
    
    
    
    
    
    public function setWritableKeys(?array $_0a20daf6005c81366c9fc0853387f6ad)
    {
        $this->writableKeys = $_0a20daf6005c81366c9fc0853387f6ad;
    }
    public function offsetExists($_1f50e30be8c2fefa6881834e71d504a2) : bool
    {
        return $this->has($_1f50e30be8c2fefa6881834e71d504a2);
    }
    public function offsetGet($_1f50e30be8c2fefa6881834e71d504a2)
    {
        return $this->get($_1f50e30be8c2fefa6881834e71d504a2);
    }
    public function offsetSet($_1f50e30be8c2fefa6881834e71d504a2, $value) : void
    {
        $this->set($_1f50e30be8c2fefa6881834e71d504a2, $value);
    }
    public function offsetUnset($_1f50e30be8c2fefa6881834e71d504a2) : void
    {
        $this->delete($_1f50e30be8c2fefa6881834e71d504a2);
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/core/classes/Config/ConfigArray.php <==
<?php
namespace Claromentis\Core\Config;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] ?: array()) + array("_bd71c3b5" . "c201fc11d" . "b82ed14ce" . "424de5" => base64_decode("aW5fY" . "XJyYX" . "k="));




class ConfigArray implements WritableConfig
{
    
    
    
    
    protected array $config;
    
    
    
    
    
    
    protected ?array $writableKeys;
    
    
    
    
    
    
    
    public function __construct(array $config = [], ?array $_e6592e635ebb74d430b5d3bac59df55b = null)
    {
        $this->config = $config;
        $this->writableKeys = $_e6592e635ebb74d430b5d3bac59df55b;
    }
    public function has(string $key) : bool
    {
        return isset($this->config[$key]);
    }
    public function get(string $key)
    {
        return $this->config[$key] ?? null;
    }
    public function getAll() : array
    {
        return $this->config;
    }
    public function set(string $key, $value) : void
    {
        if (!$this->canSet($key)) {
            return;
        }
        $this->config[$key] = $value;
    }
    public function setMany(array $values) : void
    {
        foreach ($values as $key => $value) {
            $this->set($key, $value);
        }
    }
    public function delete(string $key) : void
    {
        if ($this->canSet($key)) {
            unset($this->config[$key]);
        }
    }
    public function save() : void
    {
        
        
    }
    public function canSet(string $key) : bool
    {
        return $this->writableKeys === null || $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_bd71c3b5c20" . "1fc11db82ed1" . "4ce424de5"]($key, $this->getWritableKeys());
    }
    
    
    
    
    
    
    public function getWritableKeys() : ?array
    {
        return $this->writableKeys;
    }
    
    
    
    
    
    
    
    
    
    
    public function setWritableKeys(?array $_0a20daf6005c81366c9fc0853387f6ad)
    {
        $this->writableKeys = $_0a20daf6005c81366c9fc0853387f6ad;
    }
    public function offsetExists($_1f50e30be8c2fefa6881834e71d504a2) : bool
    {
        return $this->has($_1f50e30be8c2fefa6881834e71d504a2);
    }
    public function offsetGet($_1f50e30be8c2fefa6881834e71d504a2)
    {
        return $this->get($_1f50e30be8c2fefa6881834e71d504a2);
    }
    public function offsetSet($_1f50e30be8c2fefa6881834e71d504a2, $value) : void
    {
        $this->set($_1f50e30be8c2fefa6881834e71d504a2, $value);
    }
    public function offsetUnset($_1f50e30be8c2fefa6881834e71d504a2) : void
    {
        $this->delete($_1f50e30be8c2fefa6881834e71d504a2);
    }
}
